@@ -1073,7 +1073,11 @@ class SettingsDialog(QDialog):
         parent_layout.addWidget(self.fallback_toggle_button)
 
         # 获取当前选项 - 使用过滤后的有效选项
-        from src.interactive_feedback_server.utils import get_fallback_options
+        try:
+            from interactive_feedback_server.utils import get_fallback_options
+        except ImportError:
+            _setup_project_path()
+            from src.interactive_feedback_server.utils import get_fallback_options
 
         current_options = get_fallback_options(config)
 
@@ -1186,7 +1190,11 @@ class SettingsDialog(QDialog):
     def _save_fallback_options(self):
         """保存后备选项 - 使用null占位符标记空选项"""
         try:
-            from src.interactive_feedback_server.utils import get_config, save_config
+            try:
+                from interactive_feedback_server.utils import get_config, save_config
+            except ImportError:
+                _setup_project_path()
+                from src.interactive_feedback_server.utils import get_config, save_config
 
             # 收集所有选项，空选项用"null"占位符
             options = []
@@ -1475,9 +1483,15 @@ class SettingsDialog(QDialog):
         try:
             # 保存自定义选项开关状态
             if hasattr(self, "_custom_options_enabled"):
-                from src.interactive_feedback_server.utils import (
-                    set_custom_options_enabled,
-                )
+                try:
+                    from interactive_feedback_server.utils import (
+                        set_custom_options_enabled,
+                    )
+                except ImportError:
+                    _setup_project_path()
+                    from src.interactive_feedback_server.utils import (
+                        set_custom_options_enabled,
+                    )
 
                 set_custom_options_enabled(self._custom_options_enabled)
 
